import type { SVGProps } from 'react';

const IconAuthenticationKey = (props: SVGProps<SVGSVGElement>) => (
  <svg xmlns="http://www.w3.org/2000/svg" width={18} height={18} fill="none" {...props}>
    <g fill={props.fill ?? '#fff'}>
      <path d="M.75 5.25a.75.75 0 0 1 .75-.75H6A.75.75 0 0 1 6 6H1.5a.75.75 0 0 1-.75-.75ZM0 7.5a.75.75 0 0 1 .75-.75h6a.75.75 0 0 1 0 1.5h-6A.75.75 0 0 1 0 7.5ZM8.25 7.5A.75.75 0 0 1 9 6.75h3.75a.75.75 0 0 1 0 1.5H9a.75.75 0 0 1-.75-.75ZM.75 9a.75.75 0 0 0 0 1.5h3a.75.75 0 0 0 0-1.5h-3ZM5.25 9.75A.75.75 0 0 1 6 9h.75a.75.75 0 0 1 0 1.5H6a.75.75 0 0 1-.75-.75ZM15 6.75a.75.75 0 0 0 0 1.5h2.25a.75.75 0 0 0 0-1.5H15ZM15.75 9.75A.75.75 0 0 1 16.5 9h.75a.75.75 0 0 1 0 1.5h-.75a.75.75 0 0 1-.75-.75ZM13.5 9a.75.75 0 0 0 0 1.5h.75a.75.75 0 0 0 0-1.5h-.75ZM1.5 11.25a.75.75 0 0 0 0 1.5H6a.75.75 0 0 0 0-1.5H1.5Z" />
    </g>
  </svg>
);

export default IconAuthenticationKey;
